@@ -81,10 +81,14 @@ static unsigned short v4_fflag_masks[] = {
 static inline unsigned int
 get_be_int(unsigned char *buf)
 {
-  unsigned int retval = *(uint32_t *)buf;
-#ifndef WORDS_BIGENDIAN
-  retval = bswap_32(retval);
-#endif
+  unsigned int retval;
+  retval = buf[0];
+  retval <<= 8;
+  retval += buf[1];
+  retval <<= 8;
+  retval += buf[2];
+  retval <<= 8;
+  retval += buf[3];
   return retval;
 }
 
