@@ -535,6 +535,9 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
 
   data = id3_frame_get_raw(f);
 
+  if (f->sz < 1)
+    return 0;
+
   /* FIXME: need to test backwards -- fix mp3tag.c */
   if (backward) {
 
@@ -590,6 +593,7 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
 
     /* "(129)(9)" ==> "129" 0x00 "9" 0x00 */
     /* "(129)((I think)" ==> "129" 0x00 "(I think)" 0x00 */
+
     src = dest = data + 1;
     while (src - data < f->sz) {
 
@@ -624,9 +628,9 @@ convert_tcon(id3_frame_t f, const char *from, const char *to, int backward)
       } else {
 	*dest++ = *src++;
       }
-
-      newsz = dest - data;
     }
+
+    newsz = dest - data;
   }
 
   f->sz = newsz;
@@ -709,18 +713,16 @@ convert_frame(id3_frame_t f, int from_vers, int to_vers)
   if (from_vers == to_vers)
     return 0;
 
-  if (from_vers > to_vers) {
-    if (from_vers - to_vers > 1) {
-      ret = convert_frame(f, from_vers, from_vers - 1);
-      if (ret == -1)
-	return -1;
-    }
-  } else {
-    if (to_vers - from_vers > 1) {
-      ret = convert_frame(f, from_vers, from_vers + 1);
-      if (ret == -1)
-	return -1;
-    }
+  if (from_vers - to_vers > 1) {
+    ret = convert_frame(f, from_vers, to_vers + 1);
+    if (ret == -1)
+      return -1;
+    from_vers = to_vers + 1;
+  } else if (to_vers - from_vers > 1) {
+    ret = convert_frame(f, from_vers, to_vers - 1);
+    if (ret == -1)
+      return -1;
+    from_vers = to_vers - 1;
   }
 
   /* to and from are always one version apart at this point */
