@@ -159,10 +159,13 @@ encode_unsync(unsigned char *dest, unsigned char *src, int sz)
 static inline void
 put_be_int(unsigned char *buf, unsigned int x)
 {
-#ifndef WORDS_BIGENDIAN
-  x = bswap_32(x);
-#endif
-  *(uint32_t *)buf = x;
+  buf[3] = x & 0xFF;
+  x >>= 8;
+  buf[2] = x & 0xFF;
+  x >>= 8;
+  buf[1] = x & 0xFF;
+  x >>= 8;
+  buf[0] = x & 0xFF;
 }
 
 /* place the syncsafe encoding of x in the four bytes starting at buf */
